==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/WaterfallSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { Brush } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { Defaults } from "./Defaults";
import { runOn, markType, markDep, fromEnum } from "igniteui-angular-core";
import { Rect } from "igniteui-angular-core";
import { Pool$1 } from "igniteui-angular-core";
import { Rectangle } from "igniteui-angular-core";
import { ArrayExtension } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
/**
 * @hidden
 */
var WaterfallSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WaterfallSeries, _super);
    function WaterfallSeries() {
        var _this = _super.call(this) || this;
        _this.ab = WaterfallSeries.$;
        return _this;
    }
    WaterfallSeries.prototype.get_en = function () {
        return true;
    };
    WaterfallSeries.prototype.get_d5 = function () {
        return true;
    };
    WaterfallSeries.prototype.gz = function () {
        if (!isNaN_(this.gy)) {
            return _super.prototype.gz.call(this);
        }
        return Defaults.h;
    };
    WaterfallSeries.prototype.get_dw = function () {
        return true;
    };
    WaterfallSeries.prototype.by = function () {
        return new WaterfallSeriesView(this);
    };
    WaterfallSeries.prototype.l4 = function (a) {
        _super.prototype.l4.call(this, a);
        this.vj = a;
    };
    WaterfallSeries.prototype.preferredCategoryMode = function (a) {
        return 2;
    };
    WaterfallSeries.prototype.get_d6 = function () {
        return true;
    };
    WaterfallSeries.prototype.ms = function (a, b) {
        _super.prototype.ms.call(this, a, b);
        this.vu = a;
        this.vv = b;
    };
    WaterfallSeries.prototype.pf = function () {
        return this.vu;
    };
    WaterfallSeries.prototype.pg = function () {
        return this.vv;
    };
    WaterfallSeries.prototype.b4 = function () {
        if (this.b5 == 0) {
            return 2;
        }
        return _super.prototype.b4.call(this);
    };
    WaterfallSeries.prototype.get_c3 = function () {
        return true;
    };
    WaterfallSeries.prototype.l9 = function (a, b, c, d) {
        _super.prototype.l9.call(this, a, b, c, d);
        switch (b) {
            case WaterfallSeries.$$p[3]:
            case WaterfallSeries.$$p[2]:
            case WaterfallSeries.$$p[0]:
            case WaterfallSeries.$$p[1]:
                this.mn(false);
                break;
        }
    };
    WaterfallSeries.prototype.ez = function (a, b) {
        if (this.e2(a, b)) {
            return true;
        }
        if (this.qo(a, b)) {
            return true;
        }
        return false;
    };
    WaterfallSeries.prototype.p3 = function (a) {
        var _this = this;
        if (this.vj == null || this.vj.db == null || this.vj.db.count == 0 || this.xAxis == null) {
            return Rect.empty;
        }
        var b = this.vj.db;
        var c = this.pn(a);
        var d = -1;
        var e = this.xAxis.cg;
        var f = this.p7.right * 2;
        if (e) {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, function (g) {
                var h = _this.vj.di(g);
                return (f - c.x) < (f - (h.left + h.width / 2)) ? -1 : ((f - c.x) > (f - (h.left + h.width / 2)) ? 1 : 0);
            });
        }
        else {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, function (g) {
                var h = _this.vj.di(g);
                return c.x < (h.left + h.width / 2) ? -1 : (c.x > (h.left + h.width / 2) ? 1 : 0);
            });
        }
        if (d < 0) {
            d = ~d;
            d--;
        }
        if (d < 0) {
            d = 0;
        }
        if (d > b.count - 1) {
            d = b.count - 1;
        }
        var g = d;
        var h = d;
        if (g < 0) {
            g--;
        }
        if (h < b.count - 1) {
            h++;
        }
        var i = this.vw(g);
        var j = this.vw(d);
        var k = this.vw(h);
        var l = i.left + i.width / 2;
        var m = j.left + j.width / 2;
        var n = k.left + k.width / 2;
        var o = Math.abs(l - c.x);
        var p = Math.abs(m - c.x);
        var q = Math.abs(n - c.x);
        var r = i.containsPoint(c);
        var s = j.containsPoint(c);
        var t = k.containsPoint(c);
        if (p <= o && p <= q) {
            if (!e && t) {
                return k;
            }
            if (e && r) {
                return i;
            }
            return j;
        }
        if (o <= p && o <= q) {
            if (!e && s) {
                return j;
            }
            return i;
        }
        if (q <= p && q <= o) {
            if (e && s) {
                return j;
            }
            return k;
        }
        return Rect.empty;
    };
    WaterfallSeries.prototype.vw = function (a) {
        return this.vj.dh(a);
    };
    WaterfallSeries.prototype.r7 = function () {
        return 1;
    };
    WaterfallSeries.prototype.k2 = function (a, b) {
        _super.prototype.k2.call(this, a, b);
        this.vj.db.count = 0;
    };
    WaterfallSeries.prototype.get_t3 = function () {
        return 1;
    };
    WaterfallSeries.prototype.ge = function () {
        return this.u0.k3(this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1));
    };
    WaterfallSeries.prototype.tf = function (a, b) {
        var c = b;
        _super.prototype.tf.call(this, a, b);
        var d = b.bv;
        var e = b.bu;
        var f = this.getEffectiveViewport1(b);
        var g = this.u0.k3(d, e, f);
        var h = this.vk;
        var i = this.vl;
        var j;
        var k = this.t1(b);
        var l = NaN;
        var m = c.db;
        var n;
        var o = 0;
        this.r5.a2(this, this.sp(), runOn(this, this.rq), this.sx(b), this.sy(b));
        this.r5.r = this.vk;
        this.r5.s = this.vl;
        this.r5.k = this.vk;
        this.r5.l = this.vl;
        var p = false;
        var q = this.r5.b;
        if (q != null) {
            p = true;
        }
        var r = this.u0.cm;
        var s = this.valueColumn.count;
        var t = a.f;
        var u = this.u0;
        var v = new ScalerParams(0, d, e, this.u0.cg, f);
        var w = this.o5;
        var x = this.vu;
        var y = this.o8;
        var z = this.vv || y;
        if (a.f.count > 0) {
            j = a.f._inner[0][0] - 0.5 * g;
            var aa = a.f._inner[0][1];
            if (!isNaN_(aa)) {
                if (aa > k) {
                    n = m.item(o);
                    o++;
                    c.dg(n, j, k);
                    n.width = g;
                    n.height = Math.abs(k - aa);
                    this.r5.ak = x;
                    this.r5.ag = x;
                    this.r5.al = z;
                    this.r5.ah = z;
                    this.r5.f = true;
                    if (p) {
                        this.tb(t, 0, s, u, v, b.q);
                    }
                    this.r5.ad(n, false, false, false, false);
                    n.ap = this.r5.k;
                    n.aq = this.r5.l;
                }
                else {
                    n = m.item(o);
                    o++;
                    c.dg(n, j, aa);
                    n.width = g;
                    n.height = Math.abs(aa - k);
                    this.r5.ak = w;
                    this.r5.ag = w;
                    this.r5.al = y;
                    this.r5.ah = y;
                    this.r5.f = false;
                    if (p) {
                        this.tb(t, 0, s, u, v, b.q);
                    }
                    this.r5.ad(n, false, false, false, false);
                    n.ap = this.r5.k;
                    n.aq = this.r5.l;
                }
                l = aa;
            }
            else {
                l = k;
            }
        }
        for (var ab = 1; ab < a.f.count; ++ab) {
            var ac = a.f._inner[ab];
            j = a.f._inner[ab][0] - 0.5 * g;
            var ad = ac[1];
            if (!isNaN_(ad)) {
                n = m.item(o);
                o++;
                c.dg(n, j, Math.min(l, ad));
                n.width = g;
                n.height = Math.abs(l - ad);
                this.r5.ak = w;
                this.r5.ag = w;
                this.r5.al = y;
                this.r5.ah = y;
                this.r5.f = false;
                if (l > ad) {
                    if (p) {
                        this.tb(t, ab, s, u, v, b.q);
                    }
                }
                else {
                    this.r5.ak = x;
                    this.r5.ag = x;
                    this.r5.al = z;
                    this.r5.ah = z;
                    this.r5.f = true;
                    if (p) {
                        this.tb(t, ab, s, u, v, b.q);
                    }
                }
                this.r5.ad(n, false, false, false, false);
                n.ap = this.r5.k;
                n.aq = this.r5.l;
                l = ad;
            }
        }
        m.count = o;
        b.cy(a);
    };
    Object.defineProperty(WaterfallSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.ss;
        },
        enumerable: false,
        configurable: true
    });
    WaterfallSeries.$t = markType(WaterfallSeries, 'WaterfallSeries', HorizontalAnchoredCategorySeries.$);
    WaterfallSeries.$$p = markDep(DependencyProperty, PropertyMetadata, WaterfallSeries, 'raisePropertyChanged', ['NegativeBrush:vu:vq', [Brush.$, null], 'NegativeOutline:vv:vr', [Brush.$, null], 'RadiusX:vk:vs', [1, 0], 'RadiusY:vl:vt', [1, 0]]);
    return WaterfallSeries;
}(HorizontalAnchoredCategorySeries));
export { WaterfallSeries };
/**
 * @hidden
 */
var WaterfallSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WaterfallSeriesView, _super);
    function WaterfallSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.da = null;
        _this.dc = null;
        _this.dj = new Rectangle();
        _this.db = null;
        _this.da = a;
        _this.db = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.dk);
            $ret.activate = runOn(_this, _this.dd);
            $ret.disactivate = runOn(_this, _this.df);
            $ret.destroy = runOn(_this, _this.de);
            return $ret;
        })());
        return _this;
    }
    WaterfallSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        this.dc = new List$1(Rectangle.$, 0);
        if (!this.q) {
            this.da.ql = Defaults.c;
            this.da.g4 = Defaults.i;
            this.da.vu = Defaults.ah;
            this.da.vv = Defaults.ai;
        }
    };
    WaterfallSeriesView.prototype.dk = function () {
        var a = new Rectangle();
        this.dc.add(a);
        a._visibility = 1;
        return a;
    };
    WaterfallSeriesView.prototype.dd = function (a) {
        a._visibility = 0;
    };
    WaterfallSeriesView.prototype.df = function (a) {
        a._visibility = 1;
    };
    WaterfallSeriesView.prototype.de = function (a) {
        this.dc.remove(a);
    };
    WaterfallSeriesView.prototype.dg = function (a, b, c) {
        var d = false;
        if (a.o != c) {
            d = true;
            a.o = c;
        }
        if (a.n != b) {
            d = true;
            a.n = b;
        }
        if (d) {
            this.aq();
        }
    };
    WaterfallSeriesView.prototype.ac = function (a) {
        return this.dc._inner[a];
    };
    WaterfallSeriesView.prototype.ab = function (a) {
        var b = this.dc._inner[a];
        this.dj._visibility = b._visibility;
        this.dj.n = b.n;
        this.dj.o = b.o;
        this.dj.width = b.width;
        this.dj.height = b.height;
        var c = this.bp(a);
        this.dj._fill = c;
        this.dj._stroke = c;
        this.dj.ad = this.e.fy + 3;
        return this.dj;
    };
    WaterfallSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            for (var c = 0; c < this.dc.count; c++) {
                var d = this.aa(c, b);
                this.bd(d, c, b);
                a.w(d);
            }
        }
    };
    WaterfallSeriesView.prototype.al = function (a) {
        var e_1, _a, e_2, _b;
        _super.prototype.al.call(this, a);
        var b = 0;
        var c = new List$1(Rectangle.$, 0);
        try {
            for (var _c = __values(fromEnum(this.db.a)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var d = _d.value;
                c.add(d);
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return))
                    _a.call(_c);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        c.aa(function (e, f) {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        try {
            for (var _e = __values(fromEnum(c)), _f = _e.next(); !_f.done; _f = _e.next()) {
                var e = _f.value;
                var f = "Negative";
                if (e._fill == this.e.o5) {
                    f = "Positive";
                }
                this.e.a9.exportRectangleData(a, e, "column" + b, ["Main", f]);
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return))
                    _b.call(_e);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        b++;
    };
    WaterfallSeriesView.prototype.dh = function (a) {
        var b = this.db.item(a);
        return new Rect(0, b.n, b.o, b.width, b.height);
    };
    WaterfallSeriesView.prototype.di = function (a) {
        return new Rect(0, a.n, a.o, a.width, a.height);
    };
    WaterfallSeriesView.$t = markType(WaterfallSeriesView, 'WaterfallSeriesView', AnchoredCategorySeriesView.$);
    return WaterfallSeriesView;
}(AnchoredCategorySeriesView));
export { WaterfallSeriesView };

==> igniteui-angular-charts-17.0.0-beta.0.tgz: package/esm5/lib/WaterfallSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { Brush } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { Defaults } from "./Defaults";
import { runOn, markType, markDep, fromEnum } from "igniteui-angular-core";
import { Rect } from "igniteui-angular-core";
import { Pool$1 } from "igniteui-angular-core";
import { Rectangle } from "igniteui-angular-core";
import { ArrayExtension } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
/**
 * @hidden
 */
var WaterfallSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WaterfallSeries, _super);
    function WaterfallSeries() {
        var _this = _super.call(this) || this;
        _this.ab = WaterfallSeries.$;
        return _this;
    }
    WaterfallSeries.prototype.get_en = function () {
        return true;
    };
    WaterfallSeries.prototype.get_d5 = function () {
        return true;
    };
    WaterfallSeries.prototype.gz = function () {
        if (!isNaN_(this.gy)) {
            return _super.prototype.gz.call(this);
        }
        return Defaults.h;
    };
    WaterfallSeries.prototype.get_dw = function () {
        return true;
    };
    WaterfallSeries.prototype.by = function () {
        return new WaterfallSeriesView(this);
    };
    WaterfallSeries.prototype.l4 = function (a) {
        _super.prototype.l4.call(this, a);
        this.vj = a;
    };
    WaterfallSeries.prototype.preferredCategoryMode = function (a) {
        return 2;
    };
    WaterfallSeries.prototype.get_d6 = function () {
        return true;
    };
    WaterfallSeries.prototype.ms = function (a, b) {
        _super.prototype.ms.call(this, a, b);
        this.vu = a;
        this.vv = b;
    };
    WaterfallSeries.prototype.pf = function () {
        return this.vu;
    };
    WaterfallSeries.prototype.pg = function () {
        return this.vv;
    };
    WaterfallSeries.prototype.b4 = function () {
        if (this.b5 == 0) {
            return 2;
        }
        return _super.prototype.b4.call(this);
    };
    WaterfallSeries.prototype.get_c3 = function () {
        return true;
    };
    WaterfallSeries.prototype.l9 = function (a, b, c, d) {
        _super.prototype.l9.call(this, a, b, c, d);
        switch (b) {
            case WaterfallSeries.$$p[3]:
            case WaterfallSeries.$$p[2]:
            case WaterfallSeries.$$p[0]:
            case WaterfallSeries.$$p[1]:
                this.mn(false);
                break;
        }
    };
    WaterfallSeries.prototype.ez = function (a, b) {
        if (this.e2(a, b)) {
            return true;
        }
        if (this.qo(a, b)) {
            return true;
        }
        return false;
    };
    WaterfallSeries.prototype.p3 = function (a) {
        var _this = this;
        if (this.vj == null || this.vj.db == null || this.vj.db.count == 0 || this.xAxis == null) {
            return Rect.empty;
        }
        var b = this.vj.db;
        var c = this.pn(a);
        var d = -1;
        var e = this.xAxis.ch;
        var f = this.p7.right * 2;
        if (e) {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, function (g) {
                var h = _this.vj.di(g);
                return (f - c.x) < (f - (h.left + h.width / 2)) ? -1 : ((f - c.x) > (f - (h.left + h.width / 2)) ? 1 : 0);
            });
        }
        else {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, function (g) {
                var h = _this.vj.di(g);
                return c.x < (h.left + h.width / 2) ? -1 : (c.x > (h.left + h.width / 2) ? 1 : 0);
            });
        }
        if (d < 0) {
            d = ~d;
            d--;
        }
        if (d < 0) {
            d = 0;
        }
        if (d > b.count - 1) {
            d = b.count - 1;
        }
        var g = d;
        var h = d;
        if (g < 0) {
            g--;
        }
        if (h < b.count - 1) {
            h++;
        }
        var i = this.vw(g);
        var j = this.vw(d);
        var k = this.vw(h);
        var l = i.left + i.width / 2;
        var m = j.left + j.width / 2;
        var n = k.left + k.width / 2;
        var o = Math.abs(l - c.x);
        var p = Math.abs(m - c.x);
        var q = Math.abs(n - c.x);
        var r = i.containsPoint(c);
        var s = j.containsPoint(c);
        var t = k.containsPoint(c);
        if (p <= o && p <= q) {
            if (!e && t) {
                return k;
            }
            if (e && r) {
                return i;
            }
            return j;
        }
        if (o <= p && o <= q) {
            if (!e && s) {
                return j;
            }
            return i;
        }
        if (q <= p && q <= o) {
            if (e && s) {
                return j;
            }
            return k;
        }
        return Rect.empty;
    };
    WaterfallSeries.prototype.vw = function (a) {
        return this.vj.dh(a);
    };
    WaterfallSeries.prototype.r7 = function () {
        return 1;
    };
    WaterfallSeries.prototype.k2 = function (a, b) {
        _super.prototype.k2.call(this, a, b);
        this.vj.db.count = 0;
    };
    WaterfallSeries.prototype.get_t3 = function () {
        return 1;
    };
    WaterfallSeries.prototype.ge = function () {
        return this.u0.k4(this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1));
    };
    WaterfallSeries.prototype.tf = function (a, b) {
        var c = b;
        _super.prototype.tf.call(this, a, b);
        var d = b.bv;
        var e = b.bu;
        var f = this.getEffectiveViewport1(b);
        var g = this.u0.k4(d, e, f);
        var h = this.vk;
        var i = this.vl;
        var j;
        var k = this.t1(b);
        var l = NaN;
        var m = c.db;
        var n;
        var o = 0;
        this.r5.a2(this, this.sp(), runOn(this, this.rq), this.sx(b), this.sy(b));
        this.r5.r = this.vk;
        this.r5.s = this.vl;
        this.r5.k = this.vk;
        this.r5.l = this.vl;
        var p = false;
        var q = this.r5.b;
        if (q != null) {
            p = true;
        }
        var r = this.u0.cn;
        var s = this.valueColumn.count;
        var t = a.f;
        var u = this.u0;
        var v = new ScalerParams(0, d, e, this.u0.ch, f);
        var w = this.o5;
        var x = this.vu;
        var y = this.o8;
        var z = this.vv || y;
        if (a.f.count > 0) {
            j = a.f._inner[0][0] - 0.5 * g;
            var aa = a.f._inner[0][1];
            if (!isNaN_(aa)) {
                if (aa > k) {
                    n = m.item(o);
                    o++;
                    c.dg(n, j, k);
                    n.width = g;
                    n.height = Math.abs(k - aa);
                    this.r5.ak = x;
                    this.r5.ag = x;
                    this.r5.al = z;
                    this.r5.ah = z;
                    this.r5.f = true;
                    if (p) {
                        this.tb(t, 0, s, u, v, b.q);
                    }
                    this.r5.ad(n, false, false, false, false);
                    n.ap = this.r5.k;
                    n.aq = this.r5.l;
                }
                else {
                    n = m.item(o);
                    o++;
                    c.dg(n, j, aa);
                    n.width = g;
                    n.height = Math.abs(aa - k);
                    this.r5.ak = w;
                    this.r5.ag = w;
                    this.r5.al = y;
                    this.r5.ah = y;
                    this.r5.f = false;
                    if (p) {
                        this.tb(t, 0, s, u, v, b.q);
                    }
                    this.r5.ad(n, false, false, false, false);
                    n.ap = this.r5.k;
                    n.aq = this.r5.l;
                }
                l = aa;
            }
            else {
                l = k;
            }
        }
        for (var ab = 1; ab < a.f.count; ++ab) {
            var ac = a.f._inner[ab];
            j = a.f._inner[ab][0] - 0.5 * g;
            var ad = ac[1];
            if (!isNaN_(ad)) {
                n = m.item(o);
                o++;
                c.dg(n, j, Math.min(l, ad));
                n.width = g;
                n.height = Math.abs(l - ad);
                this.r5.ak = w;
                this.r5.ag = w;
                this.r5.al = y;
                this.r5.ah = y;
                this.r5.f = false;
                if (l > ad) {
                    if (p) {
                        this.tb(t, ab, s, u, v, b.q);
                    }
                }
                else {
                    this.r5.ak = x;
                    this.r5.ag = x;
                    this.r5.al = z;
                    this.r5.ah = z;
                    this.r5.f = true;
                    if (p) {
                        this.tb(t, ab, s, u, v, b.q);
                    }
                }
                this.r5.ad(n, false, false, false, false);
                n.ap = this.r5.k;
                n.aq = this.r5.l;
                l = ad;
            }
        }
        m.count = o;
        b.cy(a);
    };
    Object.defineProperty(WaterfallSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.ss;
        },
        enumerable: false,
        configurable: true
    });
    WaterfallSeries.$t = markType(WaterfallSeries, 'WaterfallSeries', HorizontalAnchoredCategorySeries.$);
    WaterfallSeries.$$p = markDep(DependencyProperty, PropertyMetadata, WaterfallSeries, 'raisePropertyChanged', ['NegativeBrush:vu:vq', [Brush.$, null], 'NegativeOutline:vv:vr', [Brush.$, null], 'RadiusX:vk:vs', [1, 0], 'RadiusY:vl:vt', [1, 0]]);
    return WaterfallSeries;
}(HorizontalAnchoredCategorySeries));
export { WaterfallSeries };
/**
 * @hidden
 */
var WaterfallSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WaterfallSeriesView, _super);
    function WaterfallSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.da = null;
        _this.dc = null;
        _this.dj = new Rectangle();
        _this.db = null;
        _this.da = a;
        _this.db = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.dk);
            $ret.activate = runOn(_this, _this.dd);
            $ret.disactivate = runOn(_this, _this.df);
            $ret.destroy = runOn(_this, _this.de);
            return $ret;
        })());
        return _this;
    }
    WaterfallSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        this.dc = new List$1(Rectangle.$, 0);
        if (!this.q) {
            this.da.ql = Defaults.c;
            this.da.g4 = Defaults.i;
            this.da.vu = Defaults.ah;
            this.da.vv = Defaults.ai;
        }
    };
    WaterfallSeriesView.prototype.dk = function () {
        var a = new Rectangle();
        this.dc.add(a);
        a._visibility = 1;
        return a;
    };
    WaterfallSeriesView.prototype.dd = function (a) {
        a._visibility = 0;
    };
    WaterfallSeriesView.prototype.df = function (a) {
        a._visibility = 1;
    };
    WaterfallSeriesView.prototype.de = function (a) {
        this.dc.remove(a);
    };
    WaterfallSeriesView.prototype.dg = function (a, b, c) {
        var d = false;
        if (a.o != c) {
            d = true;
            a.o = c;
        }
        if (a.n != b) {
            d = true;
            a.n = b;
        }
        if (d) {
            this.aq();
        }
    };
    WaterfallSeriesView.prototype.ac = function (a) {
        return this.dc._inner[a];
    };
    WaterfallSeriesView.prototype.ab = function (a) {
        var b = this.dc._inner[a];
        this.dj._visibility = b._visibility;
        this.dj.n = b.n;
        this.dj.o = b.o;
        this.dj.width = b.width;
        this.dj.height = b.height;
        var c = this.bp(a);
        this.dj._fill = c;
        this.dj._stroke = c;
        this.dj.ad = this.e.fy + 3;
        return this.dj;
    };
    WaterfallSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            for (var c = 0; c < this.dc.count; c++) {
                var d = this.aa(c, b);
                this.bd(d, c, b);
                a.w(d);
            }
        }
    };
    WaterfallSeriesView.prototype.al = function (a) {
        var e_1, _a, e_2, _b;
        _super.prototype.al.call(this, a);
        var b = 0;
        var c = new List$1(Rectangle.$, 0);
        try {
            for (var _c = __values(fromEnum(this.db.a)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var d = _d.value;
                c.add(d);
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return))
                    _a.call(_c);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        c.aa(function (e, f) {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        try {
            for (var _e = __values(fromEnum(c)), _f = _e.next(); !_f.done; _f = _e.next()) {
                var e = _f.value;
                var f = "Negative";
                if (e._fill == this.e.o5) {
                    f = "Positive";
                }
                this.e.a9.exportRectangleData(a, e, "column" + b, ["Main", f]);
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return))
                    _b.call(_e);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        b++;
    };
    WaterfallSeriesView.prototype.dh = function (a) {
        var b = this.db.item(a);
        return new Rect(0, b.n, b.o, b.width, b.height);
    };
    WaterfallSeriesView.prototype.di = function (a) {
        return new Rect(0, a.n, a.o, a.width, a.height);
    };
    WaterfallSeriesView.$t = markType(WaterfallSeriesView, 'WaterfallSeriesView', AnchoredCategorySeriesView.$);
    return WaterfallSeriesView;
}(AnchoredCategorySeriesView));
export { WaterfallSeriesView };
